==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/SubtypeSupertypeAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtypeSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSupertypeSet;
import io.ciera.tool.sql.ooaofooa.association.SubtypeSupertypeAssociation;
import io.ciera.tool.sql.ooaofooa.association.SubtypeSupertypeAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSubtypeSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSupertypeSetImpl;

import java.util.Arrays;
import java.util.List;


public class SubtypeSupertypeAssociationSetImpl extends InstanceSet<SubtypeSupertypeAssociationSet,SubtypeSupertypeAssociation> implements SubtypeSupertypeAssociationSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) subtypesupertypeassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) associationset.add( subtypesupertypeassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsSupertypeSet R212_relates_ClassAsSupertype() throws XtumlException {
        ClassAsSupertypeSet classassupertypeset = new ClassAsSupertypeSetImpl();
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) classassupertypeset.add( subtypesupertypeassociation.R212_relates_ClassAsSupertype() );
        return classassupertypeset;
    }
    @Override
    public ClassAsSubtypeSet R213_relates_ClassAsSubtype() throws XtumlException {
        ClassAsSubtypeSet classassubtypeset = new ClassAsSubtypeSetImpl();
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) classassubtypeset.addAll( subtypesupertypeassociation.R213_relates_ClassAsSubtype() );
        return classassubtypeset;
    }


    @Override
    public SubtypeSupertypeAssociation nullElement() {
        return SubtypeSupertypeAssociationImpl.EMPTY_SUBTYPESUPERTYPEASSOCIATION;
    }

    @Override
    public SubtypeSupertypeAssociationSet emptySet() {
      return new SubtypeSupertypeAssociationSetImpl();
    }

    @Override
    public SubtypeSupertypeAssociationSet value() {
        return this;
    }

    @Override
    public List<SubtypeSupertypeAssociation> elements() {
        return Arrays.asList(toArray(new SubtypeSupertypeAssociation[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/SubtypeSupertypeAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSubtypeSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSupertypeSet;
import io.ciera.tool.sql.ooaofooa.association.SubtypeSupertypeAssociation;
import io.ciera.tool.sql.ooaofooa.association.SubtypeSupertypeAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSubtypeSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSupertypeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SubtypeSupertypeAssociationSetImpl extends InstanceSet<SubtypeSupertypeAssociationSet,SubtypeSupertypeAssociation> implements SubtypeSupertypeAssociationSet {

    public SubtypeSupertypeAssociationSetImpl() {
    }

    public SubtypeSupertypeAssociationSetImpl(Comparator<? super SubtypeSupertypeAssociation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) subtypesupertypeassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) associationset.add( subtypesupertypeassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsSupertypeSet R212_relates_ClassAsSupertype() throws XtumlException {
        ClassAsSupertypeSet classassupertypeset = new ClassAsSupertypeSetImpl();
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) classassupertypeset.add( subtypesupertypeassociation.R212_relates_ClassAsSupertype() );
        return classassupertypeset;
    }
    @Override
    public ClassAsSubtypeSet R213_relates_ClassAsSubtype() throws XtumlException {
        ClassAsSubtypeSet classassubtypeset = new ClassAsSubtypeSetImpl();
        for ( SubtypeSupertypeAssociation subtypesupertypeassociation : this ) classassubtypeset.addAll( subtypesupertypeassociation.R213_relates_ClassAsSubtype() );
        return classassubtypeset;
    }


    @Override
    public SubtypeSupertypeAssociation nullElement() {
        return SubtypeSupertypeAssociationImpl.EMPTY_SUBTYPESUPERTYPEASSOCIATION;
    }

    @Override
    public SubtypeSupertypeAssociationSet emptySet() {
      return new SubtypeSupertypeAssociationSetImpl();
    }

    @Override
    public SubtypeSupertypeAssociationSet emptySet(Comparator<? super SubtypeSupertypeAssociation> comp) {
      return new SubtypeSupertypeAssociationSetImpl(comp);
    }

    @Override
    public SubtypeSupertypeAssociationSet value() {
        return this;
    }

    @Override
    public List<SubtypeSupertypeAssociation> elements() {
        return Arrays.asList(toArray(new SubtypeSupertypeAssociation[0]));
    }

}
